@@ -3,6 +3,7 @@
 
 import os
 import threading
+
 from ._compat import itervalues
 from ._globals import GLOBAL_LOCKER, THREAD_LOCAL
 from ._load import OrderedDict
@@ -60,7 +61,7 @@ class ConnectionPool(object):
                 GLOBAL_LOCKER.release()
 
         # if still no connection, make a new one and run the hooks
-        # note we serialize actual connectons to protect hooks
+        # note we serialize actual connections to protect hooks
         if connection is None:
             connection = self.connector()
             self.set_connection(connection, run_hooks=True)
@@ -119,7 +120,7 @@ class ConnectionPool(object):
             try:
                 GLOBAL_LOCKER.acquire()
                 pool = ConnectionPool.POOLS[self.uri]
-                if len(pool) < self.pool_size:
+                if len(pool) < int(self.pool_size):
                     pool.append(self.connection)
                     really = False
             finally:
