@@ -1,6 +1,6 @@
 from ..adapters.mssql import MSSQL
-from .base import SQLRepresenter, JSONRepresenter
-from . import representers, before_type, for_type
+from . import before_type, for_type, representers
+from .base import JSONRepresenter, SQLRepresenter
 
 
 @representers.register_for(MSSQL)
